//---------------------------------------------------------
// Copyright 2015 Ontario Institute for Cancer Research
// Written by Jared Simpson (jared.simpson@oicr.on.ca)
//---------------------------------------------------------
//
// nanopolish_consensus.cpp -- compute a new consensus sequence
// for an assembly
//
#ifndef NANOPOLISH_CONSENSUS_H
#define NANOPOLISH_CONSENSUS_H

int consensus_main(int argc, char** argv);

#endif
